@@ -46,7 +46,7 @@ use vars qw/@ISA @EXPORT @EXPORT_OK @EXPORT_TAGS
             $TIMEOUT @MODULES %MODULES %METHODS $AUTOLOAD
             @CURRENCY_RATES_MODULES $USE_EXPERIMENTAL_UA/;
 
-our $VERSION = '1.56'; # VERSION
+our $VERSION = '1.57'; # VERSION
 
 @CURRENCY_RATES_MODULES = qw/
     AlphaVantage
@@ -78,9 +78,11 @@ our $VERSION = '1.56'; # VERSION
     Fool
     Fundata
     GoldMoney
+    GoogleWeb
     HU
     IEXCloud
     IndiaMutual
+    MarketWatch
     MorningstarAU
     MorningstarCH
     MorningstarJP
@@ -103,6 +105,7 @@ our $VERSION = '1.56'; # VERSION
     Union
     XETRA
     YahooJSON
+    YahooWeb
     ZA
 /;
 
@@ -599,6 +602,15 @@ sub fetch {
     return;
   }
 
+  # Temporary Counting - not concerned about return code
+  my $COUNT_URL =
+    'http://www.panix.com/~hd-fxsts/finance-quote.html?' . $method;
+  my $count_ua = LWP::UserAgent->new(timeout => 10);
+  my $count_response = $count_ua->head($COUNT_URL);
+
+  ### COUNT_URL: $COUNT_URL
+  ### Code: $count_response->code
+
   # Failover code.  This steps through all available methods while
   # we still have failed stocks to look-up.  This loop only
   # runs a single time unless FAILOVER is defined.
@@ -1686,6 +1698,7 @@ http://www.gnucash.org/
   Finance::Quote::Fool,
   Finance::Quote::Fundata
   Finance::Quote::GoldMoney,
+  Finance::Quote::GoogleWeb,
   Finance::Quote::HU,
   Finance::Quote::IEXCloud,
   Finance::Quote::IndiaMutual,
@@ -1708,6 +1721,7 @@ http://www.gnucash.org/
   Finance::Quote::TwelveData,
   Finance::Quote::Union,
   Finance::Quote::YahooJSON,
+  Finance::Quote::YahooWeb,
   Finance::Quote::ZA
 
 You should have received the Finance::Quote hacker's guide with this package.
