@@ -26,7 +26,7 @@ use strict;
 use JSON qw( decode_json );
 use HTTP::Request::Common;
 
-our $VERSION = '1.56'; # VERSION
+our $VERSION = '1.57'; # VERSION
 
 # Alpha Vantage recommends that API call frequency does not extend far
 # beyond ~1 call per second so that they can continue to deliver
@@ -318,7 +318,7 @@ Finance::Quote::AlphaVantage - Obtain quotes from https://iexcloud.io
     
     $q = Finance::Quote->new('AlphaVantage', alphavantage => {API_KEY => 'your-alphavantage-api-key'});
 
-    %info = Finance::Quote->fetch("IBM", "AAPL");
+    %info = $q->fetch('alphavantage', 'IBM', 'AAPL');
 
 =head1 DESCRIPTION
 
