@@ -33,7 +33,7 @@ use HTML::TableExtract;
 use constant DEBUG => $ENV{DEBUG};
 use if DEBUG, 'Smart::Comments', '###';
 
-our $VERSION = '1.56'; # VERSION
+our $VERSION = '1.57'; # VERSION
 
 my $BVB_URL = 'https://bvb.ro/FinancialInstruments/Details/FinancialInstrumentsDetails.aspx?s=';
 
@@ -105,7 +105,7 @@ sub bvb {
           }
           elsif ( @$row[0] =~ m|^Date/time| ) {
             ($date) = @$row[1] =~ m|^([\d/]+)\s|;
-            $quoter->store_date(\%info, $stock, {usdate => $1}) if $date =~ m|([0-9]{1,2}/[0-9]{2}/[0-9]{4})|;
+            $quoter->store_date(\%info, $stock, {usdate => $1}) if $date =~ m|([0-9]{1,2}/[0-9]{1,2}/[0-9]{4})|;
           }
           elsif ( @$row[0] =~ m|^Last price| ) {
             ($last) = @$row[1] =~ m|^([\d\.]+)|;
@@ -159,8 +159,9 @@ Finance::Quote::BVB - Obtain quotes from Bucharest Stock Exchange.
 
     $q = Finance::Quote->new;
 
-    %info = Finance::Quote->fetch("bvb", "tlv");  # Only query bvb
-    %info = Finance::Quote->fetch("romania", "brd");     # Failover to other sources OK.
+    %info = $q->fetch("bvb", "tlv");  # Only query bvb
+
+    %info = $q->fetch("romania", "brd");     # Failover to other sources OK.
 
 =head1 DESCRIPTION
 
