@@ -1,4 +1,5 @@
 #!/usr/bin/perl -w
+# vi: set noai ts=2 sw=2 ic showmode showmatch: 
 #    This module was rewritten in June 2019 based on the 
 #    Finance::Quote::IEXCloud.pm module and prior versions of Fool.pm
 #    that carried the following copyrights:
@@ -34,9 +35,12 @@ use HTML::TreeBuilder;
 use Text::Template;
 use Encode qw(decode);
 
-our $VERSION = '1.56'; # VERSION
+use constant DEBUG => $ENV{DEBUG};
+use if DEBUG, 'Smart::Comments';
 
-my $URL = Text::Template->new(TYPE => 'STRING', SOURCE => 'http://caps.fool.com/Ticker/{$symbol}.aspx');
+our $VERSION = '1.57'; # VERSION
+
+my $URL = Text::Template->new(TYPE => 'STRING', SOURCE => 'https://caps.fool.com/Ticker/{$symbol}.aspx');
 
 sub methods { 
   return ( fool   => \&fool,
@@ -56,16 +60,22 @@ sub fool {
     
     my (%info, $symbol, $url, $reply, $code, $desc, $body);
     my $ua = $quoter->user_agent();
+    $ua->agent('Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/103.0.0.0 Safari/537.36');
     
     my $quantity = @stocks;
 
+    ### Stocks: @stocks
+
     foreach my $symbol (@stocks) {
         # Get the web page
         $url   = $URL->fill_in(HASH => {symbol => $symbol});
+        ### url: $url
         $reply = $ua->request( GET $url);
         $code  = $reply->code;
         $desc  = HTTP::Status::status_message($code);
         $body  = decode('UTF-8', $reply->content);
+
+       ### Reply: $reply
   
         if ($code != 200) {
             $info{ $symbol, 'success' } = 0;
@@ -73,6 +83,8 @@ sub fool {
             next;
         }
 
+				### Body: $body
+
         # Parse the web page
         my $root      = HTML::TreeBuilder->new_from_content($body);
         my $timestamp = $root->look_down(_tag => 'p', class => 'timestamp')->as_text;
@@ -125,7 +137,7 @@ Finance::Quote::Fool - Obtain quotes from the Motley Fool web site.
 
     $q = Finance::Quote->new;
 
-    %stockinfo = $q->fetch("fool","GE", "INTC");
+    %stockinfo = $q->fetch('fool','GE', 'INTC');
 
 =head1 DESCRIPTION
 
