@@ -31,32 +31,22 @@ use HTTP::Request::Common;
 use constant DEBUG => $ENV{DEBUG};
 use if DEBUG, 'Smart::Comments', '###';
 
-our $VERSION = '1.68_01'; # TRIAL VERSION
+our $VERSION = '1.57'; # VERSION
 
 my $GOOGLE_URL = 'https://www.google.com/finance/';
 
-our $DISPLAY    = 'GoogleWeb - Scrapes www.google.com/finance/';
-our @LABELS     = qw/symbol name last date currency method/;
-our $METHODHASH = {subroutine => \&googleweb,
-                   display    => $DISPLAY, 
-                   labels     => \@LABELS};
-
-sub methodinfo {
-    return ( 
-        googleweb => $METHODHASH,
-        bats      => $METHODHASH,
-        nyse      => $METHODHASH,
-        nasdaq    => $METHODHASH,
-    );
-}
-
-sub labels {
-  my %m = methodinfo();
-  return map {$_ => [@{$m{$_}{labels}}] } keys %m;
-}
-
 sub methods {
-  my %m = methodinfo(); return map {$_ => $m{$_}{subroutine} } keys %m;
+  return (googleweb => \&googleweb,
+          nyse      => \&googleweb,
+          nasdaq    => \&googleweb);
+}
+
+our @labels = qw/symbol name last date currency method/;
+
+sub labels { 
+  return (googleweb => \@labels,
+          nyse      => \@labels,
+          nasdaq    => \@labels); 
 }
 
 sub googleweb {
@@ -92,8 +82,8 @@ sub googleweb {
       $tree = HTML::TreeBuilder->new;
       if ($tree->parse_content($body)) {
         #
-        # Get link with exchange appended (MUTF|NYSE|NASDAQ|NYSEAMERICAN|BATS|HKG)
-        $taglink = $tree->look_down(_tag => 'a', href => qr!^./quote/$ucstock:(MUTF|NYSE|NASDAQ|NYSEAMERICAN|BATS|HKG)!);
+        # Get link with exchange appended (NYSE|NASDAQ|NYSEAMERICAN)
+        $taglink = $tree->look_down(_tag => 'a', href => qr!^./quote/$ucstock:(NYSE|NASDAQ|NYSEAMERICAN)!);
         if ($taglink) {
           $link = $taglink->attr('href');
           $link =~ s|\./quote|quote|;
@@ -132,8 +122,6 @@ sub googleweb {
         next;
       }
 
-      ### Tree: $tree
-
       # Look for div tag with data-last-price attribute
       $taglink =
         $tree->look_down(_tag => 'div', 'data-last-price' => qr|[0-9.]+|);
@@ -205,7 +193,7 @@ This module is loaded by default on a Finance::Quote object. It's also possible
 to load it explicitly by placing "googleweb" in the argument list to
 Finance::Quote->new().
 
-This module provides "googleweb", "bats", "nyse", and "nasdaq"
+This module provides "googleweb", "nyse", and "nasdaq"
 fetch methods.
 
 =head1 LABELS RETURNED
@@ -232,5 +220,4 @@ The following labels are returned:
 
 While the Google Finance web pages contain price information from other
 stock exchanges, this module currently retrieves last trade prices for
-securities listed on the NYSE, American, BATS, and NASDAQ stock exchanges.
-U.S. Mutual Funds quotes can also be retrieved with this module.
+securities listed on the NYSE, American, and NASDAQ stock exchanges.
