@@ -1,4 +1,20 @@
 #!/usr/bin/perl -w
+# vi: set ts=2 sw=2 noai ic showmode showmatch:  
+
+#    This program is free software; you can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation; either version 2 of the License, or
+#    (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU General Public License for more details.
+#
+#    You should have received a copy of the GNU General Public License
+#    along with this program; if not, write to the Free Software
+#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+#    02110-1301, USA
 
 # Version 0.1 preliminary version using Cdnfundlibrary.pm v0.4 as an example
 
@@ -14,24 +30,20 @@ use vars qw( $AMFI_URL $AMFI_NAV_LIST $AMFI_MAIN_URL);
 use LWP::UserAgent;
 use HTTP::Request::Common;
 use HTTP::Status;
-use HTML::TableExtract;
+use IO::String;
 
-our $VERSION = '1.56'; # VERSION
+our $VERSION = '1.57'; # VERSION
 
 # URLs of where to obtain information.
 
 $AMFI_MAIN_URL = ("http://www.amfiindia.com/");
 $AMFI_URL = ("https://www.amfiindia.com/spages/NAVAll.txt");
 
-# amfinavlist.txt is a cache-file. keep it until updated on the website since this is a 1meg file.
-my $cachedir = $ENV{TMPDIR} // $ENV{TEMP} // '/tmp/';
-$AMFI_NAV_LIST = $cachedir."amfinavlist.txt";
-
 sub methods { return (indiamutual => \&amfiindia,
                       amfiindia => \&amfiindia); }
 
 {
-    my @labels = qw/method source link name currency date isodate nav rprice sprice/;
+    my @labels = qw/method source link name currency date isodate nav/;
     sub labels { return (indiamutual => \@labels,
                          amfiindia => \@labels); }
 }
@@ -58,57 +70,55 @@ sub amfiindia   {
 
     ### cache : $AMFI_NAV_LIST
   
-    $reply = $ua->mirror($url, $AMFI_NAV_LIST);
+    $reply = $ua->get($url);
 
     # Make sure something is returned
     unless ($reply->is_success or $reply->code == RC_NOT_MODIFIED) {
-    foreach my $symbol (@symbols) {
-        $fundquote{$symbol,"success"} = 0;
-        $fundquote{$symbol,"errormsg"} = "HTTP failure";
-    }
-    return wantarray ? %fundquote : \%fundquote;
+      foreach my $symbol (@symbols) {
+          $fundquote{$symbol,"success"} = 0;
+          $fundquote{$symbol,"errormsg"} = "HTTP failure";
+      }
+      return wantarray ? %fundquote : \%fundquote;
     }
 
-    my $nav_fh;
-    open $nav_fh, '<', $AMFI_NAV_LIST or die "Unexpected error in opening file: $!\n";
-
+    # Attach body of response to IO::String object for file-like processing
+    my $nav_fh = IO::String->new($reply->content)
+;
     # Create a hash of all stocks requested
     my %symbolhash;
     foreach my $symbol (@symbols)
     {
         $symbolhash{$symbol} = 0;
     }
-    my $csvhead;
-    my @headhash;
 
     #Scheme Code;ISIN Div Payout/ ISIN Growth;ISIN Div Reinvestment;Scheme Name;Net Asset Value;Date
     while (<$nav_fh>) {
-    next if !/\;/;
-    chomp;
-    s/\r//;
-        my ($symbol1, $symbol2, $symbol3, $name, $nav, $date) = split /\s*\;\s*/;
-    my $symbol;
-    if (exists $symbolhash{$symbol1}) {
-        $symbol = $symbol1;
-    }
-    elsif(exists $symbolhash{$symbol2}) {
-        $symbol = $symbol2;
-    }
-    elsif(exists $symbolhash{$symbol3}) {
-        $symbol = $symbol3;
-    }
-    else {
-        next;
-    }
-    $fundquote{$symbol, "symbol"} = $symbol;
-    $fundquote{$symbol, "currency"} = "INR";
-    $fundquote{$symbol, "source"} = $AMFI_MAIN_URL;
-    $fundquote{$symbol, "link"} = $url;
-    $fundquote{$symbol, "method"} = "amfiindia";
-    $fundquote{$symbol, "name"} = $name;
-    $fundquote{$symbol, "nav"} = $nav;
-    $quoter->store_date(\%fundquote, $symbol, {eurodate => $date});
-    $fundquote{$symbol, "success"} = 1;
+      next if !/\;/;
+      chomp;
+      s/\r//;
+          my ($symbol1, $symbol2, $symbol3, $name, $nav, $date) = split /\s*\;\s*/;
+      my $symbol;
+      if (exists $symbolhash{$symbol1}) {
+          $symbol = $symbol1;
+      }
+      elsif(exists $symbolhash{$symbol2}) {
+          $symbol = $symbol2;
+      }
+      elsif(exists $symbolhash{$symbol3}) {
+          $symbol = $symbol3;
+      }
+      else {
+          next;
+      }
+      $fundquote{$symbol, "symbol"} = $symbol;
+      $fundquote{$symbol, "currency"} = "INR";
+      $fundquote{$symbol, "source"} = $AMFI_MAIN_URL;
+      $fundquote{$symbol, "link"} = $url;
+      $fundquote{$symbol, "method"} = "amfiindia";
+      $fundquote{$symbol, "name"} = $name;
+      $fundquote{$symbol, "nav"} = $nav;
+      $quoter->store_date(\%fundquote, $symbol, {eurodate => $date});
+      $fundquote{$symbol, "success"} = 1;
     }
     close($nav_fh);
 
@@ -134,10 +144,11 @@ Finance::Quote::IndiaMutual  - Obtain Indian mutual fund prices from amfiindia.c
 
     $q = Finance::Quote->new;
 
-    %stockinfo = $q->fetch("indiamutual", "amfiindia-code"); # Can
-failover to other methods
-    %stockinfo = $q->fetch("amfiindia", "amfiindia-code"); # Use this
-module only.
+    # Can failover to other methods
+    %stockinfo = $q->fetch("indiamutual", "amfiindia-code");
+
+    # Use this module only
+    %stockinfo = $q->fetch("amfiindia", "amfiindia-code");
 
     # NOTE: currently no failover methods exist for indiamutual
 
@@ -159,14 +170,29 @@ http://www.amfiindia.com/nav-history-download
 
 Information available from amfiindia may include the following labels:
 
-method link source name currency nav rprice sprice.  The link
-label will be a url location for the NAV list table for all funds.
+=over
+
+=item method
+
+=item link
+
+=item source
+
+=item name
+
+=item currency
+
+=item nav
+
+=back
+
+The link label will be a url location for the NAV list table for all funds.
 
 =head1 NOTES
 
 AMFI provides a link to download a text file containing all the
-NAVs. This file is mirrored in a local file /tmp/amfinavlist.txt. The local
-mirror serves only as a cache and can be safely removed.
+L<NAVs|https://www.amfiindia.com/spages/NAVAll.txt>. It is processed
+in memory using the L<IO::String> Perl module.
 
 =head1 SEE ALSO
 
