@@ -31,36 +31,24 @@ use HTML::TreeBuilder;
 use constant DEBUG => $ENV{DEBUG};
 use if DEBUG, 'Smart::Comments', '###';
 
-our $VERSION = '1.68_01'; # TRIAL VERSION
-
-our $DISPLAY    = 'MarketWatch';
-our $FEATURES   = {};
-our @LABELS     = qw/symbol name last date currency method/;
-our $METHODHASH = {subroutine => \&marketwatch, 
-                   display => $DISPLAY, 
-                   labels => \@LABELS,
-                   features => $FEATURES};
-
-sub methodinfo {
-  return ( 
-      marketwatch => $METHODHASH,
-      nyse        => $METHODHASH,
-      nasdaq      => $METHODHASH,
-  );
-}
-
-sub methods {
-  my %m = methodinfo();
-  return map {$_ => $m{$_}{subroutine} } keys %m;
-}
-
-sub labels {
-  my %m = methodinfo();
-  return map {$_ => [@{$m{$_}{labels}}] } keys %m;
-}
+our $VERSION = '1.57'; # VERSION
 
 my $MW_URL = 'https://www.marketwatch.com/investing/stock/';
 
+sub methods {
+  return (marketwatch => \&marketwatch,
+          nyse        => \&marketwatch,
+          nasdaq      => \&marketwatch);
+}
+
+our @labels = qw/symbol name last date currency method/;
+
+sub labels { 
+  return (marketwatch => \@labels,
+          nyse        => \@labels,
+          nasdaq      => \@labels); 
+}
+
 sub marketwatch {
 
   my $quoter = shift;
@@ -68,32 +56,15 @@ sub marketwatch {
   my (%info, $tree, $url, $reply);
   my $ua = $quoter->user_agent();
 
-  $ua->agent("Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/115.0.0.0 Safari/537.36");
-
-  my @ua_headers = (
-    'Accept' => 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8',
-    'Accept-Language' => 'en-US,en;q=0.9',
-    'Accept-Encoding' => 'gzip, deflate, br',
-    'Connection' => 'keep-alive',
-    'Upgrade-Insecure-Requests' => '1',
-    'Sec-Fetch-Dest' => 'document',
-    'Sec-Fetch-Mode' => 'navigate',
-    'Sec-Fetch-Site' => 'none',
-    'Sec-Fetch-User' => '?1',
-  );
-
-  # Enable cookie handling (websites often check if you can store cookies)
-  $ua->cookie_jar({});
-
   foreach my $stock (@stocks) {
 
     $url   = $MW_URL . $stock;
-    $reply = $ua->get($url, @ua_headers);
+    $reply = $ua->get($url);
 
     my $code    = $reply->code;
     my $desc    = HTTP::Status::status_message($code);
     my $headers = $reply->headers_as_string;
-    my $body    = $reply->decoded_content;
+    my $body    = decode('UTF-8', $reply->content);
 
     ### Body: $body
 
