@@ -40,7 +40,7 @@ use LWP::UserAgent;
 use HTTP::Request::Common;
 use HTTP::Cookies;
 
-our $VERSION = '1.56'; # VERSION
+our $VERSION = '1.57'; # VERSION
 
 $MSTARUK_MAIN_URL   =   "http://www.morningstar.co.uk";
 $MSTARUK_LOOK_UP    =   "http://www.morningstar.co.uk/uk/funds/SecuritySearchResults.aspx?search=";
@@ -254,8 +254,8 @@ Finance::Quote::MorningstarUK - Obtain UK Unit Trust quotes from morningstar.co.
 
     $q = Finance::Quote->new;
 
-    %info = Finance::Quote->fetch("mstaruk","<isin> ...");  # Only query morningstar.co.uk using ISINs
-    %info = Finance::Quote->fetch("ukfunds","<isin> ...");  # Failover to other sources
+    %info = $q->fetch("mstaruk","<isin> ...");  # Only query morningstar.co.uk using ISINs
+    %info = $q->fetch("ukfunds","<isin> ...");  # Failover to other sources
 
 =head1 DESCRIPTION
 
