@@ -42,7 +42,7 @@ use LWP::UserAgent;
 use HTTP::Request::Common;
 use POSIX;
 
-our $VERSION = '1.56'; # VERSION
+our $VERSION = '1.57'; # VERSION
 
 # URLs of where to obtain information
 $TSP_URL      = 'https://www.tsp.gov/data/fund-price-history.csv';
@@ -131,9 +131,9 @@ Finance::Quote::TSP - Obtain fund prices for US Federal Government Thrift Saving
 
     $q = Finance::Quote->new;
 
-    %info = Finance::Quote->fetch("tsp","c");       #get value of C - Common Stock Index Investment Fund
-    %info = Finance::Quote->fetch("tsp","l2040");   #get value of the L2040 Lifecycle Fund
-    %info = Finance::Quote->fetch("tsp","lincome"); #get value of the LINCOME Lifecycle Fund
+    %info = $q->fetch('tsp','c');       #get value of C - Common Stock Index Investment Fund
+    %info = $q->fetch('tsp','l2040');   #get value of the L2040 Lifecycle Fund
+    %info = $q->fetch('tsp','lincome'); #get value of the LINCOME Lifecycle Fund
 
 =head1 DESCRIPTION
 
