@@ -7,10 +7,14 @@
 
 perl -MData::Dumper -MFinance::Quote -le '$q = Finance::Quote->new(); print Dumper { $q->fetch("treasurydirect", @ARGV) };' 912810QT8 912810QY7
 
+=end comment
+
 =cut
 
 package Finance::Quote::TreasuryDirect;
-require 5.004;
+use strict;
+use warnings;
+
 
 #
 # Modification of Rolf Endres' Finance::Quote::ZA
@@ -19,10 +23,7 @@ require 5.004;
 # April, 2018
 #
 
-our $VERSION = '1.56'; # VERSION
-
-use strict;
-use warnings;
+our $VERSION = '1.57'; # VERSION
 
 use vars qw /$VERSION/ ;
 
@@ -30,7 +31,6 @@ use LWP::UserAgent;
 use HTTP::Request::Common;
 use HTML::TableExtract;
 use HTTP::Request;
-use Data::Dumper;
 
 my $TREASURY_DIRECT_URL = 'https://www.treasurydirect.gov/GA-FI/FedInvest/todaySecurityPriceDate.htm';
 
@@ -166,6 +166,8 @@ sub treasurydirect_ymd {
 
   print "\n \n \n \n[debug]: ++++ ==== ++++ ==== ++++ ==== ++++ ==== END OF TABLE DUMP ++++ ==== ++++ ==== ++++ ==== ++++ ==== \n \n \n \n";
 
+=end comment
+
 =cut
 
   my %bonds;
@@ -214,9 +216,11 @@ sub treasurydirect_ymd {
 
 1;
 
+__END__
+
 =head1 NAME
 
-Finance::Quote::TreasuryDirect - Obtain individual bond quotes from Treasury Direct
+Finance::Quote::TreasuryDirect - Obtain bond quotes from Treasury Direct
 
 =head1 SYNOPSIS
 
@@ -224,7 +228,7 @@ Finance::Quote::TreasuryDirect - Obtain individual bond quotes from Treasury Dir
 
     $q = Finance::Quote->new;
 
-    # Don't know anything about failover yet...
+    %info = $q->fetch('treasurydirect', '912810QT8');
 
 =head1 DESCRIPTION
 
