@@ -15,19 +15,18 @@
 #    02110-1301, USA
 
 package Finance::Quote::TwelveData;
+use strict;
 
-require 5.005;
 
 use constant DEBUG => $ENV{DEBUG};
 use if DEBUG, 'Smart::Comments';
 
-use strict;
 use JSON qw( decode_json );
 use HTTP::Request::Common;
 use Text::Template;
 use DateTime::Format::Strptime qw( strptime strftime );
 
-our $VERSION = '1.56'; # VERSION
+our $VERSION = '1.57'; # VERSION
 
 my $URL      = Text::Template->new(TYPE => 'STRING', SOURCE => 'https://api.twelvedata.com/quote?symbol={$symbol}&apikey={$token}');
 my $THROTTLE = 1.05 * 60.0/8.0;  # 5% more than maximum seconds / request for free tier
@@ -45,7 +44,7 @@ sub parameters {
     our @labels = qw/symbol name exchange currency isodate currency open high low close/;
 
     sub labels {
-        return ( iexcloud => \@labels );
+        return ( twelvedata => \@labels );
     }
 }
 
@@ -148,7 +147,7 @@ Finance::Quote::TwelveData - Obtain quotes from https://twelvedata.com
     
     $q = Finance::Quote->new('TwelveData', twelvedata => {API_KEY => 'your-twelvedata-api-key'});
 
-    %info = Finance::Quote->fetch("IBM", "AAPL");
+    %info = $q->fetch('twelvedata', 'IBM', 'AAPL');
 
 =head1 DESCRIPTION
 
