@@ -33,7 +33,7 @@ use HTTP::Request::Common;
 use HTML::TableExtract;
 use Time::Piece;
 
-our $VERSION = '1.56'; # VERSION
+our $VERSION = '1.57'; # VERSION
 
 my $YIND_URL_HEAD = 'https://query2.finance.yahoo.com/v11/finance/quoteSummary/';
 my $YIND_URL_TAIL = '?modules=price,summaryDetail,defaultKeyStatistics';
@@ -119,7 +119,7 @@ sub yahoo_json {
 
                 $info{ $stocks, "success" } = 1;
                 $info{ $stocks, "exchange" } =
-                    "Sourced from Yahoo Finance (as JSON)";
+                    $json_resources_price->{'exchangeName'};
                 $info{ $stocks, "method" } = "yahoo_json";
                 $info{ $stocks, "name" }   = $stocks . ' (' . $json_name . ')';
                 $info{ $stocks, "type" }   = $json_type;
@@ -214,7 +214,7 @@ Finance::Quote::YahooJSON - Obtain quotes from Yahoo Finance through JSON call
 
     $q = Finance::Quote->new;
 
-    %info = Finance::Quote->fetch("yahoo_json","SBIIN.NS");
+    %info = $q->fetch('yahoo_json','SBIN.NS');
 
 =head1 DESCRIPTION
 
